@@ -167,7 +167,7 @@ class BaseDeployment(object):
         """
         full_manage_dir = Path(self.target_dir, Path(self.manage_dir))
         with virtualenv(str(self.virtualenv_dir), full_manage_dir):
-            sudo('manage.py %s --settings=%s' % (arg, self.settings))
+            sudo('./manage.py %s --settings=%s' % (arg, self.settings))
 
     @easyfabtask
     def upgrade_requirements(self):
